@@ -1,5 +1,5 @@
 # Licensed under the Apache License: http://www.apache.org/licenses/LICENSE-2.0
-# For details: https://github.com/nedbat/coveragepy/blob/master/NOTICE.txt
+# For details: https://github.com/coveragepy/coveragepy/blob/main/NOTICE.txt
 
 """Control of and utilities for debugging."""
 
@@ -19,8 +19,8 @@ import reprlib
 import sys
 import traceback
 import types
-from collections.abc import Iterable, Iterator, Mapping
-from typing import IO, Any, Callable, Final, overload
+from collections.abc import Callable, Iterable, Iterator, Mapping
+from typing import IO, Any, Final, overload
 
 from coverage.misc import human_sorted_items, isolate_module
 from coverage.types import AnyCallable, TWritable
@@ -139,7 +139,7 @@ def info_header(label: str) -> str:
     return "--{:-<60s}".format(" " + label + " ")
 
 
-def info_formatter(info: Iterable[tuple[str, Any]]) -> Iterator[str]:
+def info_formatter(info: Iterable[tuple[str, Any]]) -> Iterable[str]:
     """Produce a sequence of formatted lines from info.
 
     `info` is a sequence of pairs (label, data).  The produced lines are
@@ -155,14 +155,15 @@ def info_formatter(info: Iterable[tuple[str, Any]]) -> Iterator[str]:
         if data == []:
             data = "-none-"
         prefix = f"{label:>{LABEL_LEN}}: "
-        if isinstance(data, tuple) and len(str(data)) < 30:
-            yield f"{prefix}{data}"
-        elif isinstance(data, (list, set, tuple)):
-            for e in data:
-                yield f"{prefix}{e}"
-                prefix = " " * (LABEL_LEN + 2)
-        else:
-            yield f"{prefix}{data}"
+        match data:
+            case tuple() if len(str(data)) < 30:
+                yield f"{prefix}{data}"
+            case tuple() | list() | set():
+                for e in data:
+                    yield f"{prefix}{e}"
+                    prefix = " " * (LABEL_LEN + 2)
+            case _:
+                yield f"{prefix}{data}"
 
 
 def write_formatted_info(
@@ -351,10 +352,14 @@ def simplify(v: Any) -> Any:  # pragma: debugging
         return v
 
 
+def ppformat(v: Any) -> str:  # pragma: debugging
+    """Debug helper to pretty-print data, including SimpleNamespace objects."""
+    return pprint.pformat(simplify(v), indent=4, compact=True, sort_dicts=True, width=140)
+
+
 def pp(v: Any) -> None:  # pragma: debugging
     """Debug helper to pretty-print data, including SimpleNamespace objects."""
-    # Might not be needed in 3.9+
-    pprint.pprint(simplify(v))
+    print(ppformat(v))
 
 
 def filter_text(text: str, filters: Iterable[Callable[[str], str]]) -> str:
